package com.ruoyi.web.controller.info;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.domain.entity.SysUser;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.SysHesuanConfiguration;
import com.ruoyi.system.service.ISysHesuanConfigurationService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 对比规则配置Controller
 * 
 * @author ruoyi
 * @date 2022-10-10
 */
@RestController
@RequestMapping("/system/configuration")
public class SysHesuanConfigurationController extends BaseController
{
    @Autowired
    private ISysHesuanConfigurationService sysHesuanConfigurationService;

    /**
     * 查询对比规则配置列表
     */
    //@PreAuthorize("@ss.hasPermi('system:configuration:list')")
    @GetMapping("/list")
    public TableDataInfo list(SysHesuanConfiguration sysHesuanConfiguration)
    {
        List<SysHesuanConfiguration> list = sysHesuanConfigurationService.selectSysHesuanConfigurationList(sysHesuanConfiguration);
        return getDataTable(list);
    }

    /**
     * 导出对比规则配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:configuration:export')")
    @Log(title = "对比规则配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysHesuanConfiguration sysHesuanConfiguration)
    {
        List<SysHesuanConfiguration> list = sysHesuanConfigurationService.selectSysHesuanConfigurationList(sysHesuanConfiguration);
        ExcelUtil<SysHesuanConfiguration> util = new ExcelUtil<SysHesuanConfiguration>(SysHesuanConfiguration.class);
        util.exportExcel(response, list, "对比规则配置数据");
    }

    /**
     * 获取对比规则配置详细信息
     */
    //@PreAuthorize("@ss.hasPermi('system:configuration:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(sysHesuanConfigurationService.selectSysHesuanConfigurationById(id));
    }

    /**
     * 新增对比规则配置
     */
    //@PreAuthorize("@ss.hasPermi('system:configuration:add')")
    @Log(title = "对比规则配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SysHesuanConfiguration sysHesuanConfiguration)
    {
        SysUser user = getLoginUser().getUser();
        return toAjax(sysHesuanConfigurationService.insertSysHesuanConfiguration(sysHesuanConfiguration,user));
    }

    /**
     * 修改对比规则配置
     */
    //@PreAuthorize("@ss.hasPermi('system:configuration:edit')")
    @Log(title = "对比规则配置", businessType = BusinessType.UPDATE)
    @PostMapping("put")
    public AjaxResult edit(@RequestBody SysHesuanConfiguration sysHesuanConfiguration)
    {
        return toAjax(sysHesuanConfigurationService.updateSysHesuanConfiguration(sysHesuanConfiguration));
    }

    /**
     * 删除对比规则配置
     */
    //@PreAuthorize("@ss.hasPermi('system:configuration:remove')")
    @Log(title = "对比规则配置", businessType = BusinessType.DELETE)
    @GetMapping(value = "/delete/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sysHesuanConfigurationService.deleteSysHesuanConfigurationByIds(ids));
    }
}
